@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, 2010, 2011, 2012, 2013
+ * Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -42,14 +42,14 @@
 # include <iconv.h>
 #endif
 
-#include "gettext.h"
+#include "base/gettext.h"
 #define _(string) gettext(string)
 
-#include "dbg.h"
-#include "exc.h"
-#include "msg.h"
+#include "base/dbg.h"
+#include "base/exc.h"
+#include "base/msg.h"
 
-#include "str.h"
+#include "base/str.h"
 
 
 #if HAVE_VASPRINTF
@@ -481,6 +481,60 @@ namespace str
         return hr;
     }
 
+    /* Create an RFC2822-style time string, like "Fri,  4 Dec 2009 22:29:43 +0100 (CET)" */
+    /* Code taken from mpop 1.0.29:
+     * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
+     * Martin Lambers <marlam@marlam.de>
+     * License: GPLv3+
+     */
+    std::string rfc2822_time(time_t t)
+    {
+        struct tm gmt, *lt;
+        char tz_offset_sign;
+        int tz_offset_hours;
+        int tz_offset_minutes;
+        const char* weekday[7] = { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" };
+        const char* month[12] = { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul",
+            "Aug", "Sep", "Oct", "Nov", "Dec" };
+        char rfc2822_timestamp[32];
+
+        /* Calculate a RFC 2822 timestamp. strftime() is unreliable for this because
+         * it is locale dependant, and because the timezone offset conversion
+         * specifier %z is not portable. */
+        /* copy the struct tm, because the subsequent call to localtime() will
+         * overwrite it */
+        gmt = *gmtime(&t);
+        lt = localtime(&t);
+        tz_offset_minutes = (lt->tm_hour - gmt.tm_hour) * 60
+            + lt->tm_min - gmt.tm_min
+            + (lt->tm_year - gmt.tm_year) * 24 * 60
+            + (lt->tm_yday - gmt.tm_yday) * 24 * 60;
+        if (tz_offset_minutes < 0)
+        {
+            tz_offset_sign = '-';
+            tz_offset_minutes = -tz_offset_minutes;
+        }
+        else
+        {
+            tz_offset_sign = '+';
+        }
+        tz_offset_hours = tz_offset_minutes / 60;
+        tz_offset_minutes %= 60;
+        if (tz_offset_hours > 99)
+        {
+            /* Values equal to or larger than 24 are not meaningful, but we just
+             * make sure that the value fits into two digits. If the system time is
+             * broken, we cannot fix it. */
+            tz_offset_hours = 99;
+        }
+        snprintf(rfc2822_timestamp, sizeof(rfc2822_timestamp),
+                "%s, %02d %s %04d %02d:%02d:%02d %c%02d%02d",
+                weekday[lt->tm_wday], lt->tm_mday, month[lt->tm_mon],
+                lt->tm_year + 1900, lt->tm_hour, lt->tm_min, lt->tm_sec,
+                tz_offset_sign, tz_offset_hours, tz_offset_minutes);
+        return std::string(rfc2822_timestamp);
+    }
+
     /* Get the name of the user's character set */
     std::string localcharset()
     {
