@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2010, 2011, 2012, 2013
+ * Copyright (C) 2010, 2011, 2012, 2013, 2014
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -36,6 +36,8 @@
 #include "lib.h"
 
 char *program_name = NULL;
+int* gtatool_argc = NULL;
+char** gtatool_argv = NULL;
 FILE *gtatool_stdin = NULL;
 FILE *gtatool_stdout = NULL;
 
