@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# Copyright (C) 2010, 2011
+# Copyright (C) 2010, 2011, 2013
 # Martin Lambers <marlam@marlam.de>
 #
 # Copying and distribution of this file, with or without modification, are
@@ -23,4 +23,13 @@ cmp "$TMPD"/xb.gta "$TMPD"/b.gta
 $GTA dimension-add -d 0 < "$TMPD"/a.gta > "$TMPD"/xc.gta
 cmp "$TMPD"/xc.gta "$TMPD"/c.gta
 
+$GTA create -d 10 -n5 > "$TMPD"/empty0.gta
+$GTA create -d 10,1 -n5 > "$TMPD"/empty1.gta
+$GTA create -c uint8 -n5 > "$TMPD"/empty2.gta
+$GTA create -d 1 -c uint8 -n5 > "$TMPD"/empty3.gta
+$GTA dimension-add "$TMPD"/empty0.gta > "$TMPD"/xempty1.gta
+cmp "$TMPD"/empty1.gta "$TMPD"/xempty1.gta
+$GTA dimension-add "$TMPD"/empty2.gta > "$TMPD"/xempty3.gta
+cmp "$TMPD"/empty3.gta "$TMPD"/xempty3.gta
+
 rm -r "$TMPD"
